@@ -31,7 +31,6 @@ import qualified Propellor.Property.Fail2Ban as Fail2Ban
 import qualified Propellor.Property.FlashKernel as FlashKernel
 import qualified Propellor.Property.Laptop as Laptop
 import qualified Propellor.Property.LightDM as LightDM
-import qualified Propellor.Property.Debootstrap as Debootstrap
 import qualified Propellor.Property.HostingProvider.Linode as Linode
 import qualified Propellor.Property.SiteSpecific.GitHome as GitHome
 import qualified Propellor.Property.SiteSpecific.GitAnnexBuilder as GitAnnexBuilder
@@ -48,7 +47,7 @@ hosts =                 --                  (o)  `
 	, dragon
 	, oyster
 	, house
-	, sky
+	, gate
 	, kite
 	, sparrow
 	, beaver
@@ -62,47 +61,43 @@ hosts =                 --                  (o)  `
 darkstar :: Host
 darkstar = host "darkstar.kitenet.net" $ props
 	& osDebian Unstable X86_64
-	& ipv6 "2001:4830:1600:187::2"
 	& Hostname.sane
 	& Hostname.mailname
 	& Apt.serviceInstalledRunning "swapspace"
 	& Laptop.powertopAutoTuneOnBoot
 	& Laptop.trimSSD
-	& Grub.cmdline_Linux_default "i915.enable_psr=1"
 	! Grub.cmdline_Linux_default "quiet"
 	& User.hasGroup (User "joey") (Group "dialout")
 
 	& JoeySites.dkimMilter
 	& JoeySites.postfixSaslPasswordClient
-	-- & JoeySites.alarmClock "*-*-* 7:30" (User "joey")
-	--	"/usr/bin/timeout 45m /home/joey/bin/goodmorning"
 	& JoeySites.laptopSoftware
 	& JoeySites.userDirHtml
+	& JoeySites.thinkPadLedsOff
 	& Ssh.userKeys (User "joey") hostContext
 		[ (SshEd25519, "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAICfFntnesZcYz2B2T41ay45igfckXRSh5uVffkuCQkLv joey@darkstar")
 		]
-	& imageBuiltFor house
+	! imageBuiltFor house
 		(RawDiskImage "/srv/house.img")
 		(Debootstrapped mempty)
 
 dragon :: Host
 dragon = host "dragon.kitenet.net" $ props
-	& ipv6 "2001:4830:1600:187::2"
 	& JoeySites.dkimMilter
 	& JoeySites.postfixSaslPasswordClient
 
 oyster :: Host
 oyster = host "oyster.kitenet.net" $ props
-	& standardSystem (Stable "buster") X86_64
+	& standardSystem (Stable "bookworm") X86_64
 		["Unreliable server. Anything here may be lost at any time!" ]
-	& ipv4 "45.138.157.89"
+	& ipv4 "45.87.155.118"
 
 	& User.hasPassword (User "root")
 	& Apt.unattendedUpgrades
 
 house :: Host
 house = host "house.lan" $ props
-	& standardSystem Testing ARMHF [ "House mail computer." ]
+	& standardSystem (Stable "bookworm") ARMHF [ "House main computer." ]
 	& Apt.removed ["rsyslog"]
 	
 	& cubietech_Cubietruck
@@ -133,53 +128,69 @@ house = host "house.lan" $ props
 		(Context "house.joeyh.name")
 		(SshEd25519, "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIMAmVYddg/RgCbIj+cLcEiddeFXaYFnbEJ3uGj9G/EyV joey@honeybee")
 	
-	-- Use iwd to connect to wifi on whatever usb wifi is connected.
-	& Apt.installed ["iwd"]
-	& File.hasContent "/var/lib/iwd/.known_network.freq"
-		[ "[7085c93b-9e5f-5cdb-a13d-bf72db7c3adf]"
-		, "name=/var/lib/iwd//hollow.open"
-		, "list= 2457"
+	-- Use network-manager to connect to wifi on whatever usb wifi is connected.
+	& Apt.installed ["network-manager"]
+	& File.hasContent "/etc/NetworkManager/system-connections/hollow.nmconnection"
+		[ "[connection]"
+		, "id=hollow"
+		, "uuid=dfa672be-79d2-4151-9a26-ae7cb3729681"
+		, "type=wifi"
+		, "interface-name=wlan1"
+		, ""
+		, "[wifi]"
+		, "mode=infrastructure"
+		, "ssid=hollow"
+		, ""
+		, "[ipv4]"
+		, "method=manual"
+		, "addresses=10.1.1.2/24"
+		, "gateway=10.1.1.1"
+		, "dns=10.1.1.1"
+		, ""
+		, "[ipv6]"
+		, "addr-gen-mode=default"
+		, "method=auto"
+		, ""
+		, "[proxy]"
 		]
-	& File.hasContent "/var/lib/iwd/hollow.open"
-		[ "[IPv4]"
-		, "Address=10.1.1.2"
-		, "Netmask=255.255.255.0"
-		, "Gateway=10.1.1.1"
-		, "Broadcast=10.1.1.255"
-		, "DNS=10.1.1.1"
-		]
-	& Systemd.enabled "iwd"
+	& Systemd.enabled "NetworkManager"
 	& "/etc/resolv.conf" `File.containsLine` "search lan"
 
-	& JoeySites.homeNAS
 	& Apt.installed ["mtr-tiny", "iftop", "screen", "nmap"]
-	-- Currently manually building the xr_usb_serial module.
-	& Apt.installed ["linux-headers-armmp-lpae"]
 	& Postfix.satellite
 
-sky :: Host
-sky = host "sky.lan" $ props
-	& standardSystem Testing ARMHF [ "Wifi router." ]
+-- This is a raspberry pi and is installed using https://raspi.debian.net/tested-images/
+-- before propellor is run on it.
+gate :: Host
+gate = host "gate.lan" $ props
+	& standardSystem (Stable "trixie") ARM64 [ "Wifi router." ]
 	& Apt.removed ["rsyslog"]
 	
 	& Apt.installed ["raspi-firmware", "firmware-misc-nonfree"]
 	& Apt.serviceInstalledRunning "systemd-timesyncd" -- no hardware clock
 
+	& "/etc/systemd/network/10-gate.link" `File.containsLines`
+		[ "[Match]"
+		, "MACAddress=9c:ef:d5:fc:d6:f3" -- USB wifi adapter
+		, ""
+		, "[Link]"
+		, "Name=" ++ JoeySites.wifiInterface ifs
+		]
+
 	& Ssh.hostKeys hostContext
 		[ (SshEcdsa, "ecdsa-sha2-nistp256 AAAAE2VjZHNhLXNoYTItbmlzdHAyNTYAAAAIbmlzdHAyNTYAAABBBG19v7K59SzFp/OntM9iyhlKOj2pShFSPJeqR1aiYhPF2NqztcmsY6WvIDqh6jmaISnyV1IqZZ60zvGTVRoOyMY=")
 		]
 	& Ssh.userKeys (User "joey") hostContext
 		[ (SshEd25519, "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIOmwEfM5qTjA7xuJgygEgHfa1Y/WrRBpu7xBY8D82ul+")
 		]
+	& Postfix.satellite
 
 	& JoeySites.connectStarlinkDish ifs
-	& JoeySites.homeRouter ifs "hollow" JoeySites.hostapd2GhzConfig_mt76
-	& Apt.installed ["mtr-tiny", "iftop", "screen", "nmap", "net-tools"]
-	& Postfix.satellite
+	& JoeySites.homeRouter "gate.lan" ifs "hollow" JoeySites.hostapd2GhzConfig_mt76
   where
 	ifs = JoeySites.Interfaces
 		{ JoeySites.ethernetInterface = "eth0"
-		, JoeySites.wifiInterface = "wlan0"
+		, JoeySites.wifiInterface = "wlan-gate"
 		, JoeySites.wifiInterfaceOld = "wlan1"
 		}
 
@@ -188,12 +199,9 @@ sky = host "sky.lan" $ props
 -- with propellor.
 kite :: Host
 kite = host "kite.kitenet.net" $ props
-	& standardSystemUnhardened Testing X86_64 [ "Welcome to kite!" ]
+	& standardSystemUnhardened (Stable "trixie") X86_64 [ "Welcome to kite!" ]
 	& ipv4 "66.228.36.95"
-	-- disabled because I've had complaints of mail bouncing, and it
-	-- seems mail servers are only trying ipv6 and then bouncing if
-	-- they have an ipv6 routing issue.
-	-- & ipv6 "2600:3c03::f03c:91ff:fe73:b0d2"
+	& ipv6 "2600:3c03::f03c:91ff:fe73:b0d2"
 	& alias "kitenet.net"
 	& Ssh.hostKeys (Context "kitenet.net")
 		[ (SshDsa, "ssh-dss AAAAB3NzaC1kc3MAAACBAO9tnPUT4p+9z7K6/OYuiBNHaij4Nzv5YVBih1vMl+ALz0gYAj8RWJzXmqp5buFAyfgOoLw+H9s1bBS01Sy3i07Dm6cx1fWG4RXL/E/3w1tavX99GD2bBxDBu890ebA5Tp+eFRJkS9+JwSvFiF6CP7NbVjifCagoUO56Ig048RwDAAAAFQDPY2xM3q6KwsVQliel23nrd0rV2QAAAIEAga3hj1hL00rYPNnAUzT8GAaSP62S4W68lusErH+KPbsMwFBFY/Ib1FVf8k6Zn6dZLh/HH/RtJi0JwdzPI1IFW+lwVbKfwBvhQ1lw9cH2rs1UIVgi7Wxdgfy8gEWxf+QIqn62wG+Ulf/HkWGvTrRpoJqlYRNS/gnOWj9Z/4s99koAAACBAM/uJIo2I0nK15wXiTYs/NYUZA7wcErugFn70TRbSgduIFH6U/CQa3rgHJw9DCPCQJLq7pwCnFH7too/qaK+czDk04PsgqV0+Jc7957gU5miPg50d60eJMctHV4eQ1FpwmGGfXxRBR9k2ZvikWYatYir3L6/x1ir7M0bA9IzNU45")
@@ -214,6 +222,7 @@ kite = host "kite.kitenet.net" $ props
 	& Fail2Ban.installed -- since ssh password authentication is allowed
 	-- Allow ssh -R to forward ports via kite
 	& Ssh.setSshdConfig "GatewayPorts" "clientspecified"
+	& Apt.installed ["wtmpdb"]
 	& Apt.serviceInstalledRunning "ntp"
 	& "/etc/timezone" `File.hasContent` ["US/Eastern"]
 	
@@ -274,9 +283,6 @@ kite = host "kite.kitenet.net" $ props
 	& alias "kgb.kitenet.net"
 	& JoeySites.kgbServer
 	
-	& alias "podcatcher.kitenet.net"
-	& JoeySites.podcatcher
-
 	& alias "ns4.kitenet.net"
 	& myDnsPrimary "kitenet.net"
 		[ (RelDomain "mouse-onion", CNAME $ AbsDomain "htieo6yu2qtcn2j3.onion")
@@ -313,11 +319,14 @@ kite = host "kite.kitenet.net" $ props
 	& Systemd.nspawned (GitAnnexBuilder.autoBuilderContainer
 		(GitAnnexBuilder.standardAutoBuilder True)
 		Unstable X86_64 mempty Nothing (Cron.Times "15 * * * *") "2h")
+	& Systemd.nspawned (GitAnnexBuilder.autoBuilderContainer
+		(GitAnnexBuilder.standardAutoBuilder True)
+		Unstable X86_32 mempty Nothing (Cron.Times "30 * * * *") "2h")
 	& Apt.serviceInstalledRunning "swapspace"
 
 sparrow :: Host
 sparrow = host "sparrow.kitenet.net" $ props
-	& standardSystem Testing ARM64 [ "Welcome to sparrow!" ]
+	& standardSystem (Stable "trixie") ARM64 [ "Welcome to sparrow!" ]
 	& ipv4 "128.140.52.168"
 	& ipv6 "2a01:4f8:c17:ed3a::1"
 	& Apt.installed ["ssh"]
@@ -325,16 +334,6 @@ sparrow = host "sparrow.kitenet.net" $ props
 	-- In case compiler needs more than available ram
 	& Apt.serviceInstalledRunning "swapspace"
 
-	& Systemd.nspawned (GitAnnexBuilder.autoBuilderContainer
-		-- qemu hangs running unattended-upgrades on i386
-		-- so disable installing that
-		(GitAnnexBuilder.standardAutoBuilder False)
-		Unstable X86_32 mempty Nothing (Cron.Times "30 * * * *") "4h")
-	& Systemd.nspawned (GitAnnexBuilder.autoBuilderContainer
-		GitAnnexBuilder.stackAutoBuilder
-		(Stable "jessie") X86_32 
-		(Debootstrap.UseOldGpgKeyring Debootstrap.:+ Debootstrap.DebootstrapMirror "http://archive.debian.org/debian/")
-		(Just "ancient") (Cron.Times "45 * * * *") "4h")
 	& Systemd.nspawned (GitAnnexBuilder.autoBuilderContainer
 		(GitAnnexBuilder.standardAutoBuilder True)
 		Testing ARM64 mempty Nothing (Cron.Times "1 * * * *") "2h")
@@ -344,9 +343,21 @@ sparrow = host "sparrow.kitenet.net" $ props
 		(Just "ancient") (Cron.Times "20 * * * *") "2h")
 	& Systemd.nspawned (GitAnnexBuilder.autoBuilderContainer
 		(GitAnnexBuilder.armAutoBuilder (GitAnnexBuilder.standardAutoBuilder True))
-		Testing ARMEL mempty Nothing (Cron.Times "15 15 * * *") "2h")
+		Testing ARMEL mempty Nothing (Cron.Times "40 * * * *") "2h")
 	
-	& Systemd.nspawned ancientKitenet
+	! Systemd.nspawned ancientKitenet
+	
+	& Borg.backup "/root" (JoeySites.rsyncNetBorgRepo "sparrow.borg" []) Cron.Daily
+		[ ]
+		[ Borg.KeepDays 7
+		, Borg.KeepWeeks 4
+		, Borg.KeepMonths 3
+		]
+		`requires` Ssh.knownHost hosts "usw-s002.rsync.net" (User "root")
+		`requires` Ssh.userKeys (User "root")
+			(Context "sparrow.kitenet.net")
+			[ (SshEd25519, "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAID3mgBXLLzp+DnzZqH6Azly+0uZe/d2TK69oZYcFz+gN root@sparrow")
+			]
 
 beaver :: Host
 beaver = host "beaver.kitenet.net" $ props
@@ -364,7 +375,6 @@ sow = host "sow.kitenet.net" $ props
 
 mouse :: Host
 mouse = host "mouse.kitenet.net" $ props
-	& ipv4 "67.223.19.96"
 	& Apt.installed ["ssh"]
 	& Tor.installed
 	& Tor.hiddenServiceAvailable "ssh" (Port 22)
@@ -403,7 +413,7 @@ pell = host "pell.branchable.com" $ props
 	& alias "dist-bugs.kitenet.net"
 	& alias "family.kitenet.net"
 
-	& osDebian (Stable "buster") X86_32
+	& osDebian (Stable "bookworm") X86_32
 	& Apt.installed ["linux-image-686-pae"]
 	& Apt.stdSourcesList `onChange` Apt.upgrade
 	& Apt.unattendedUpgrades
@@ -423,7 +433,7 @@ pell = host "pell.branchable.com" $ props
 -- Exhibit: kite's 90's website on port 1994.
 ancientKitenet :: Systemd.Container
 ancientKitenet = Systemd.debContainer "ancient-kitenet" $ props
-	& standardContainer (Stable "buster") ARM64
+	& standardContainer (Stable "trixie") ARM64
 	& alias hn
 	& Git.cloned (User "root") "git://kitenet-net.branchable.com/" "/var/www/html"
 		(Just "remotes/origin/old-kitenet.net")
