@@ -16,7 +16,6 @@ import qualified Propellor.Property.Cron as Cron
 import qualified Propellor.Property.Service as Service
 import qualified Propellor.Property.User as User
 import qualified Propellor.Property.Group as Group
-import qualified Propellor.Property.Sudo as Sudo
 import qualified Propellor.Property.Borg as Borg
 import qualified Propellor.Property.Apache as Apache
 import qualified Propellor.Property.Postfix as Postfix
@@ -24,10 +23,8 @@ import qualified Propellor.Property.Systemd as Systemd
 import qualified Propellor.Property.Network as Network
 import qualified Propellor.Property.Fail2Ban as Fail2Ban
 import qualified Propellor.Property.LetsEncrypt as LetsEncrypt
-import qualified Propellor.Property.Mount as Mount
 import Utility.Split
 
-import Data.List
 import System.Posix.Files
 
 kgbServer :: Property (HasInfo + DebianLike)
@@ -60,7 +57,7 @@ gitServer hosts = propertyList "git.kitenet.net setup" $ props
 	& Apt.installed ["kgb-client"]
 	& File.hasPrivContentExposed "/etc/kgb-bot/kgb-client.conf" anyContext
 		`requires` File.dirExists "/etc/kgb-bot/"
-	& Git.daemonRunning "/srv/git"
+	& Git.daemonService "/srv/git"
 	& "/etc/cgitrc" `File.hasContent`
 		[ "clone-url=https://git.joeyh.name/git/$CGIT_REPO_URL git://git.joeyh.name/$CGIT_REPO_URL"
 		, "css=/cgit-css/cgit.css"
@@ -216,38 +213,11 @@ ircBouncer = propertyList "IRC bouncer" $ props
   where
 	conf = "/home/znc/.znc/configs/znc.conf"
 
-githubBackup :: Property (HasInfo + DebianLike)
-githubBackup = propertyList "github-backup box" $ props
-	& Apt.installed ["github-backup", "moreutils"]
-	& githubKeys
-	& Cron.niceJob "github-backup run" (Cron.Times "30 4 * * *") (User "joey")
-		"/home/joey/lib/backup" backupcmd
-  where
-	backupcmd = intercalate "&&" $
-		[ "mkdir -p github"
-		, "cd github"
-		, ". $HOME/.github-keys"
-		, "github-backup joeyh"
-		]
-
-githubKeys :: Property (HasInfo + UnixLike)
-githubKeys =
-	let f = "/home/joey/.github-keys"
-	in File.hasPrivContent f anyContext
-		`onChange` File.ownerGroup f (User "joey") (Group "joey")
-
-
 rsyncNetBackup :: [Host] -> Property DebianLike
 rsyncNetBackup hosts = Cron.niceJob "rsync.net copied in daily" (Cron.Times "30 5 * * *")
 	(User "joey") "/home/joey/lib/backup" "mkdir -p rsync.net && rsync --delete -az 2318@usw-s002.rsync.net: rsync.net"
 	`requires` Ssh.knownHost hosts "usw-s002.rsync.net" (User "joey")
 
-podcatcher :: Property DebianLike
-podcatcher = Cron.niceJob "podcatcher run hourly" (Cron.Times "55 * * * *")
-	(User "joey") "/home/joey/lib/sound/podcasts"
-	"timeout 2h xargs git-annex importfeed -c annex.genmetadata=true < feeds; mr --quiet update"
-	`requires` Apt.installed ["git-annex", "myrepos"]
-
 spamdEnabled :: Property DebianLike
 spamdEnabled = Apt.serviceInstalledRunning "spamd"
 
@@ -267,12 +237,19 @@ spamassassinConfigured = propertyList "spamassassin configured" $ props
 		]
 		`describe` "spamassassin configured"
 		`requires` Apt.serviceInstalledRunning "cron"
+	& "/etc/spamassassin/local.cf" `File.containsLines`
+		-- dnswl.org started intentionally sending false responses
+		-- for spam senders when they don't like the amount of
+		-- queries being made. This causes spamassassin to skip
+		-- all other checks and miss flagging spam. This is
+		-- irresponsible behavior, and so they should not be used.
+		[ "dns_query_restriction deny dnswl.org"
+		]
 
 kiteMailServer :: Property (HasInfo + DebianLike)
 kiteMailServer = propertyList "kitenet.net mail server" $ props
 	& Postfix.installed
 	& Apt.installed ["postfix-pcre"]
-	& Apt.serviceInstalledRunning "postgrey"
 	& spamassassinConfigured
 	& Apt.serviceInstalledRunning "spamass-milter"
 	-- Add -m to prevent modifying messages Subject or body.
@@ -281,20 +258,6 @@ kiteMailServer = propertyList "kitenet.net mail server" $ props
 		`onChange` Service.restarted "spamass-milter"
 		`describe` "spamass-milter configured"
 
-	& Apt.serviceInstalledRunning "amavisd-milter"
-	& "/etc/default/amavisd-milter" `File.containsLines`
-		[ "# Propellor deployed"
-		, "MILTERSOCKET=/var/spool/postfix/amavis/amavis.sock"
-		, "MILTERSOCKETOWNER=\"postfix:postfix\""
-		, "MILTERSOCKETMODE=\"0660\""
-		]
-		`onChange` Service.restarted "amavisd-milter"
-		`describe` "amavisd-milter configured for postfix"
-	& Apt.serviceInstalledRunning "clamav-freshclam"
-	-- Workaround https://bugs.debian.org/569150
-	& Cron.niceJob "amavis-expire" Cron.Daily (User "root") "/"
-		"find /var/lib/amavis/virusmails/ -type f -ctime +2 -delete"
-
 	& dkimInstalled
 
 	& Postfix.saslAuthdInstalled
@@ -309,11 +272,8 @@ kiteMailServer = propertyList "kitenet.net mail server" $ props
 		[ "# Global maildrop filter file (deployed with propellor)"
 		, "DEFAULT=\"$HOME/Maildir\""
 		, "MAILBOX=\"$DEFAULT/.\""
-		, "# Filter spam to a spam folder, unless .keepspam exists"
 		, "if (/^X-Spam-Status: Yes/)"
 		, "{"
-		, "  `test -e \"$HOME/.keepspam\"`"
-		, "  if ( $RETURNCODE != 0 )"
 		, "  to ${MAILBOX}spam"
 		, "}"
 		]
@@ -372,11 +332,11 @@ kiteMailServer = propertyList "kitenet.net mail server" $ props
 		, "smtpd_sasl_security_options = noanonymous"
 		, "smtpd_sasl_local_domain = kitenet.net"
 
-		, "# Enable postgrey and sasl auth and client certs."
-		, "smtpd_recipient_restrictions = permit_tls_clientcerts,permit_sasl_authenticated,,permit_mynetworks,reject_unauth_destination,check_policy_service inet:127.0.0.1:10023"
+		, "# Enable sasl auth and client certs."
+		, "smtpd_recipient_restrictions = permit_tls_clientcerts,permit_sasl_authenticated,,permit_mynetworks,reject_unauth_destination"
 
-		, "# Enable spamass-milter, amavis-milter (opendkim is not enabled because it causes mails forwarded from eg gmail to be rejected)"
-		, "smtpd_milters = unix:/spamass/spamass.sock unix:amavis/amavis.sock"
+		, "# Enable spamass-milter (opendkim is not enabled because it causes mails forwarded from eg gmail to be rejected)"
+		, "smtpd_milters = unix:/spamass/spamass.sock"
 		, "# opendkim is used for outgoing mail"
 		, "non_smtpd_milters = inet:localhost:8891"
 		, "milter_connect_macros = j {daemon_name} v {if_name} _"
@@ -389,7 +349,7 @@ kiteMailServer = propertyList "kitenet.net mail server" $ props
 		, "smtpd_tls_key_file = /etc/ssl/private/postfix.pem"
 		, "smtpd_tls_loglevel = 1"
 		, "smtpd_tls_received_header = yes"
-		, "smtpd_use_tls = yes"
+		, "smtpd_tls_security_level = may"
 		, "smtpd_tls_ask_ccert = yes"
 		, "smtpd_tls_session_cache_database = btree:${data_directory}/smtpd_scache"
 
@@ -398,7 +358,7 @@ kiteMailServer = propertyList "kitenet.net mail server" $ props
 		, "smtp_tls_cert_file = /etc/ssl/certs/postfix.pem"
 		, "smtp_tls_key_file = /etc/ssl/private/postfix.pem"
 		, "smtp_tls_loglevel = 1"
-		, "smtp_use_tls = yes"
+		, "smtp_tls_security_level = may"
 		, "smtp_tls_session_cache_database = btree:${data_directory}/smtp_scache"
 
 		, "# Allow larger attachments, up to 200 mb."
@@ -422,6 +382,14 @@ kiteMailServer = propertyList "kitenet.net mail server" $ props
 		"!include auth-passwdfile.conf.ext"
 		`onChange` Service.restarted "dovecot"
 		`describe` "dovecot auth.conf"
+	& "/etc/dovecot/conf.d/10-ssl.conf" `File.containsLines`
+		[ "ssl_cert = </etc/letsencrypt/live/kitenet.net/fullchain.pem"
+		, "ssl_key = </etc/letsencrypt/live/kitenet.net/privkey.pem"
+		]
+		`onChange` Service.reloaded "dovecot"
+		`describe` "dovecot ssl.conf using letsencrypt"
+	& Cron.niceJob "dovecot restarts to update letsenctypt certificate"
+		Cron.Daily (User "root") "/" "systemctl restart dovecot"
 	& File.hasPrivContent dovecotusers ctx
 		`onChange` (dovecotusers `File.mode`
 			combineModes [ownerReadMode, groupReadMode])
@@ -519,7 +487,7 @@ postfixSaslPasswordClient = combineProperties "postfix uses SASL password to aut
 		, "smtp_sasl_auth_enable = yes"
 		, "smtp_tls_security_level = encrypt"
 		, "smtp_sasl_tls_security_options = noanonymous"
-		, "relayhost = kitenet.net:587"
+		, "relayhost = kitenet.net:465"
 		, "smtp_sasl_password_maps = hash:/etc/postfix/sasl_passwd"
 		]
 		`onChange` Postfix.reloaded
@@ -607,7 +575,7 @@ legacyWebSites = propertyList "legacy web sites" $ props
 		, "rewriterule (.*) http://joeyh.name$1 [r]"
 		]
 	& alias "house.joeyh.name"
-	& apacheSite "house.joeyh.name"
+	& Apache.httpsVirtualHost' "house.joeyh.name" "/srv/web/house.joeyh.name" letos
 		[ "DocumentRoot /srv/web/house.joeyh.name"
 		, "<Directory /srv/web/house.joeyh.name>"
 		, "  Options Indexes ExecCGI"
@@ -729,6 +697,29 @@ alarmClock oncalendar (User user) command = combineProperties "goodmorning timer
 	& "/etc/systemd/logind.conf" `ConfFile.containsIniSetting`
 		("Login", "LidSwitchIgnoreInhibited", "no")
 
+epsolarUsbSetup :: Property UnixLike
+epsolarUsbSetup = propertyList "epsolar usb setup" $ props
+	& "/etc/udev/rules.d/99-epsolar-usb.rules" `File.hasContent`
+		-- Each epever usb cable has its own serial number and gets
+		-- its own stable device name.
+		[ "SUBSYSTEM==\"tty\", ATTRS{idVendor}==\"04e2\", ATTRS{idProduct}==\"1411\", ATTRS{serial}==\"G9107376441\", SYMLINK+=\"epsolar1\""
+		, "SUBSYSTEM==\"tty\", ATTRS{idVendor}==\"1a86\", ATTRS{idProduct}==\"55d3\", ATTRS{serial}==\"5876071260\", SYMLINK+=\"epsolar2\""
+		, "SUBSYSTEM==\"tty\", ATTRS{idVendor}==\"1a86\", ATTRS{idProduct}==\"55d3\", ATTRS{serial}==\"5875017909\", SYMLINK+=\"epsolar3\""
+		, "SUBSYSTEM==\"tty\", ATTRS{idVendor}==\"1a86\", ATTRS{idProduct}==\"55d3\", ATTRS{serial}==\"5876071261\", SYMLINK+=\"epsolar4\""
+		, "SUBSYSTEM==\"tty\", ATTRS{idVendor}==\"1a86\", ATTRS{idProduct}==\"55d3\", ATTRS{serial}==\"5875017825\", SYMLINK+=\"epsolar5\""
+		, "SUBSYSTEM==\"tty\", ATTRS{idVendor}==\"1a86\", ATTRS{idProduct}==\"55d3\", ATTRS{serial}==\"589A039325\", SYMLINK+=\"epsolar6\""
+		]
+	-- The xr-serial module wants to handle the epever usb cables
+	-- (at least older ones, new ones are handled by ACM), but
+	-- it does not work in linux 6.1. Instead I am currently installing
+	-- an out of tree module, xr_usb_serial_common. In linux 6.6,
+	-- the xr-serial module has been reported to work,
+	-- see https://github.com/kasbert/epsolar-tracer/pull/61#issuecomment-2056442735
+	& "/etc/modprobe.d/blacklist.conf" `File.containsLines`
+		[ "blacklist xr-serial"
+		, "blacklist xr-serial"
+		]
+
 house :: IsContext c => User -> [Host] -> c -> (SshKeyType, Ssh.PubKeyText) -> Property (HasInfo + DebianLike)
 house user hosts ctx sshkey = propertyList "home automation" $ props
 	& Apache.installed
@@ -736,6 +727,7 @@ house user hosts ctx sshkey = propertyList "home automation" $ props
 	& Git.cloned user "https://git.joeyh.name/git/joey/house.git" d Nothing
 	& websitesymlink
 	& build
+	& epsolarUsbSetup
 	& Systemd.enabled setupservicename
 		`requires` setupserviceinstalled
 		`onChange` Systemd.started setupservicename
@@ -767,7 +759,6 @@ house user hosts ctx sshkey = propertyList "home automation" $ props
 			user (userGroup user)
 		`requires` File.dirExists (takeDirectory sshkeyfile)
 		`requires` Ssh.knownHost hosts "kitenet.net" user
-	& File.hasPrivContentExposed "/etc/darksky-forecast-url" anyContext
   where
 	d = "/home/joey/house"
 	sshkeyfile = d </> ".ssh/key"
@@ -804,7 +795,7 @@ house user hosts ctx sshkey = propertyList "home automation" $ props
 		, ""
 		, "[Install]"
 		, "WantedBy=multi-user.target"
-		, "WantedBy=house-controller.target"
+		, "WantedBy=house-controller.service"
 		]
 	controllerservicename = "house-controller"
 	controllerservicefile = "/etc/systemd/system/" ++ controllerservicename ++ ".service"
@@ -853,9 +844,9 @@ house user hosts ctx sshkey = propertyList "home automation" $ props
 		, ""
 		, "[Install]"
 		, "WantedBy=multi-user.target"
-		, "WantedBy=house-poller.target"
-		, "WantedBy=house-controller.target"
-		, "WantedBy=house-watchdog.target"
+		, "WantedBy=house-poller.service"
+		, "WantedBy=house-controller.service"
+		, "WantedBy=house-watchdog.service"
 		]
 	-- Any changes to the rsync command will need my .authorized_keys
 	-- rsync server command to be updated too.
@@ -878,16 +869,15 @@ data Interfaces = Interfaces
 connectStarlinkDish :: Interfaces -> Property DebianLike
 connectStarlinkDish ifs = propertyList "connected via starlink dish" $ props
 	-- Use dhcpcd for ipv6 prefix delegation to the wifi interface.
-	& Apt.installed ["dhcpcd"]
-	-- dhcpcd is run by ifup on boot. When the daemon was enabled,
-	-- that somehow prevented prefix delegation from happening,
-	-- so disable the daemon from being run by systemd.
-	& Systemd.stopped "dhcpcd"
-	& Systemd.masked "dhcpcd"
+	& Apt.installed ["dhcpcd-base"]
+	& Apt.removed ["isc-dhcp-client"]
 	& "/etc/dhcpcd.conf" `File.containsLine`
 		("ia_pd 1 " ++ wifiInterface ifs)
 	& "/etc/dhcpcd.conf" `File.lacksLine`
 		("ia_pd 1 " ++ wifiInterfaceOld ifs)
+	-- Avoid using dns servers sent by starlink.
+	& "/etc/dhcpcd.conf" `File.containsLine`
+		"nohook resolv.conf"
 	& Network.dhcp (ethernetInterface ifs)
 		`requires` Network.cleanInterfacesFile
 
@@ -902,8 +892,8 @@ connectStarlinkRouter ifs = propertyList "connected via starlink router" $ props
 		`requires` Network.cleanInterfacesFile
 
 -- My home router, running hostapd and dnsmasq.
-homeRouter :: Interfaces -> String -> HostapdConfig -> Property DebianLike
-homeRouter ifs wifinetworkname (HostapdConfig hostapdconfig) = propertyList "home router" $ props
+homeRouter :: String -> Interfaces -> String -> HostapdConfig -> Property DebianLike
+homeRouter hn ifs wifinetworkname (HostapdConfig hostapdconfig) = propertyList "home router" $ props
 	& File.notPresent (Network.interfaceDFile (wifiInterfaceOld ifs))
 	& Network.static (wifiInterface ifs) (IPv4 "10.1.1.1") Nothing
 		`requires` Network.cleanInterfacesFile
@@ -916,8 +906,9 @@ homeRouter ifs wifinetworkname (HostapdConfig hostapdconfig) = propertyList "hom
 		`requires` File.hasContent "/etc/default/hostapd"
 			[ "DAEMON_CONF=/etc/hostapd/hostapd.conf" ]
 		`onChange` Service.running "hostapd"
+	! Systemd.masked "hostapd"
 	& Systemd.enabled "hostapd"
-	& File.hasContent "/etc/resolv.conf"
+	& File.hasContent "/etc/resolv.conf.head"
 		[ "domain kitenet.net"
 		, "search kitenet.net"
 		, "nameserver 8.8.8.8"
@@ -933,7 +924,7 @@ homeRouter ifs wifinetworkname (HostapdConfig hostapdconfig) = propertyList "hom
 		-- controller wants to know when clients disconnect
 		, "dhcp-range=10.1.1.100,10.1.1.150,10m"
 		, "no-hosts"
-		, "address=/sky.lan/10.1.1.1"
+		, "address=/" ++ hn ++ "/10.1.1.1"
 		, "address=/house.lan/10.1.1.2"
 		-- allow accessing starlink dish when it's not online yet
 		, "address=/dishy.starlink.com/192.168.100.1"
@@ -960,7 +951,11 @@ homeRouter ifs wifinetworkname (HostapdConfig hostapdconfig) = propertyList "hom
 		, "};"
 		]
 		`onChange` Service.restarted "radvd"
-	& "/etc/sysctl.conf" `File.containsLine` "net.ipv6.conf.all.forwarding=1"
+	& "/etc/sysctl.d/ip-forwarding.conf" 
+		`File.containsLine` "net.ipv6.conf.all.forwarding=1"
+	-- Programs that I find useful on a router.
+	& Apt.installed ["net-tools", "wireless-tools"]
+	& Apt.installed ["mtr-tiny", "iftop", "screen", "nmap"]
 
 -- | Enable IP masqerading, on whatever other interfaces come up, besides the
 -- provided intif.
@@ -987,11 +982,12 @@ laptopSoftware :: Property DebianLike
 laptopSoftware = Apt.installed
 	[ "intel-microcode", "acpi"
 	, "procmeter3", "xfce4", "procmeter3", "unclutter-xfixes"
-	, "mplayer", "fbreader", "firefox", "chromium"
+	, "vlc", "mpv", "mplayer", "fbreader", "foliate", "firefox", "chromium"
+	, "yt-dlp"
 	, "libdatetime-event-sunrise-perl", "libtime-duration-perl"
 	, "network-manager", "network-manager-openvpn-gnome", "openvpn"
-	, "gtk-redshift", "powertop"
-	, "gimp", "gthumb", "inkscape", "sozi", "xzgv", "hugin"
+	, "powertop"
+	, "gimp", "gthumb", "inkscape", "xzgv", "hugin"
 	, "mpc", "mpd", "ncmpc", "sonata", "mpdtoys"
 	, "bsdgames", "nethack-console"
 	, "xmonad", "libghc-xmonad-dev", "libghc-xmonad-contrib-dev"
@@ -999,23 +995,25 @@ laptopSoftware = Apt.installed
 	, "mairix", "offlineimap", "mutt", "slrn"
 	, "mtr", "nmap", "whois", "wireshark", "tcpdump", "iftop"
 	, "pmount", "tree", "pv"
-	, "arbtt", "hledger", "bc"
+	, "hledger", "bc"
 	, "apache2", "ikiwiki", "libhighlight-perl"
 	, "avahi-daemon", "avahi-discover"
-	, "pal"
+	, "pal", "ncal"
 	, "yeahconsole", "xkbset", "xinput"
 	, "assword", "pumpa"
 	, "vorbis-tools", "audacity"
-	, "ekiga"
-	, "bluez-firmware", "blueman", "pulseaudio-module-bluetooth"
+	, "bluez-firmware", "blueman", "pulseaudio-module-bluetooth" 
+	, "pulseaudio-utils"
 	, "fwupd"
-	, "xul-ext-ublock-origin", "xul-ext-pdf.js", "xul-ext-status4evar"
+	, "webext-ublock-origin-firefox", "webext-ublock-origin-chromium"
 	, "vim-syntastic", "vim-fugitive"
 	, "adb", "gthumb"
 	, "w3m", "sm", "weechat"
 	, "borgbackup", "wipe", "smartmontools", "libgfshare-bin"
 	, "units"
-	, "virtualbox", "virtualbox-guest-additions-iso", "qemu-kvm"
+	, "libnotify-bin"
+	, "libmodbus-dev"
+	, "qemu-kvm"
 	]
 	`requires` baseSoftware
 	`requires` devSoftware
@@ -1023,17 +1021,17 @@ laptopSoftware = Apt.installed
 baseSoftware :: Property DebianLike
 baseSoftware = Apt.installed
 	[ "bash", "bash-completion", "vim", "screen", "less", "moreutils"
-	, "git", "mr", "etckeeper", "git-annex", "ssh", "vim-vimoutliner"
+	, "git", "mr", "etckeeper", "git-annex", "ssh" --, "vim-vimoutliner"
 	]
 
 devSoftware :: Property DebianLike
 devSoftware = Apt.installed
 	[ "build-essential", "debhelper", "devscripts"
 	, "ghc", "cabal-install", "haskell-stack"
-	, "hothasktags", "hdevtools", "hlint"
+	, "hasktags", "hlint"
 	, "gdb", "time"
 	, "dpkg-repack", "lintian"
-	, "pristine-tar", "github-backup"
+	, "pristine-tar"
 	]
 
 cubieTruckOneWire :: Property DebianLike
@@ -1072,161 +1070,6 @@ cubieTruckOneWire = utilitysetup
 		, "};"
 		]
 
--- My home networked attached storage server.
-homeNAS :: Property DebianLike
-homeNAS = propertyList "home NAS" $ props
-	& Apt.installed ["uhubctl"]
-	& "/etc/udev/rules.d/52-startech-hub.rules" `File.hasContent`
-		[ "# let users power control startech hub with uhubctl"
-		, "ATTR{idVendor}==\"" ++ hubvendor ++ "\", ATTR{idProduct}==\"005a\", MODE=\"0666\""
-		]
-	& autoMountDrivePort "archive-10"
-		(USBHubPort hubvendor 1)
-		(USBDriveId wd "1230")
-		(Just "archive-oldest")
-	& autoMountDrivePort "archive-11"
-		(USBHubPort hubvendor 2)
-		(USBDriveId wd "25ee")
-		(Just "archive-older")
-	& autoMountDrivePort "archive-12"
-		(USBHubPort hubvendor 3)
-		(USBDriveId seagate "3322")
-		(Just "archive-old")
-	& autoMountDrivePort "archive-13"
-		(USBHubPort hubvendor 4)
-		(USBDriveId wd "25a3")
-		(Just "archive")
-	& autoMountDrivePort "archive-14"
-		(USBHubPort hubvendor 2)
-		(USBDriveId wd "25a3")
-		Nothing
-	& autoMountDrive "passport" Nothing
-	& Apt.installed ["git-annex", "borgbackup"]
-  where
-	hubvendor = "0409"
-	wd = "1058"
-	seagate = "0bc2"
-
-data USBHubPort = USBHubPort
-	{ hubVendor :: String
-	, hubPort :: Int
-	}
-
-data USBDriveId = USBDriveId
-	{ driveVendorId :: String
-	, driveProductId :: String
-	}
-
--- Makes a USB drive with the given label automount, and unmount after idle
--- for a while.
---
--- The hub port is turned on and off automatically as needed, using
--- uhubctl.
-autoMountDrivePort :: Mount.Label -> USBHubPort -> USBDriveId -> Maybe FilePath -> Property DebianLike
-autoMountDrivePort label hp drive malias = propertyList desc $ props
-	& File.hasContent ("/etc/systemd/system/" ++ hub)
-		[ "[Unit]"
-		, "Description=Startech usb hub port " ++ show (hubPort hp) ++ " vendor " ++ driveVendorId drive ++ " driveid " ++ driveProductId drive
-		, "PartOf=" ++ mount
-		, "[Service]"
-		, "Type=oneshot"
-		, "RemainAfterExit=true"
-		, "ExecStart=/bin/sh -c 'uhubctl -a on " ++ selecthubport ++ "'"
-		, "ExecStop=/bin/sh -c 'uhubctl -a off " ++ selecthubport
-			-- Powering off the port does not remove device
-			-- files, so ask udev to remove the devfile; it will
-			-- be added back after the drive next spins up
-			-- and so avoid mount happening before the drive is
-			-- spun up.
-			-- (This only works when the devfile is in
-			-- by-label.)
-			++ "; udevadm trigger --action=remove " ++ devfile ++ " || true'"
-		, "[Install]"
-		, "WantedBy="
-		]
-		`onChange` Systemd.daemonReloaded
-	& autoMountDrive' 
-		[ "Requires=" ++ hub
-		, "After=" ++ hub
-		] label malias
-  where
-	devfile = "/dev/disk/by-label/" ++ label
-	mountpoint = "/media/joey/" ++ label
-	desc = "auto mount with hub port power control " ++ mountpoint
-	hub = "startech-hub-port-" ++ show (hubPort hp) ++ "-vendor-" ++ driveVendorId drive ++ "-drivedid-" ++ driveProductId drive ++ ".service"
-	mount = svcbase ++ ".mount"
-	svcbase = Systemd.escapePath mountpoint
-	selecthubport = unwords
-		[ "-p", show (hubPort hp)
-		, "-n", hubVendor hp
-		, "-l", concat
-			-- The hub's location id, eg "1-1.4", does not seem
-			-- as stable as uhubctl claims it will be,
-			-- and the vendor is not sufficient since I have 2
-			-- hubs from the same vendor. So search for the
-			-- drive lsusb to find that. This works even if the
-			-- port is powered off, as long as it's been on at
-			-- some point before.
-			[ "$(lsusb -tvv | perl -lne \"if (\\\\$h && m!/sys/bus/usb/devices/(.*?) !) {\\\\$v=\\\\$1}; if (m/Hub/) { \\\\$h=1 } else { \\\\$h=0 }; if (/"
-			, driveVendorId drive ++ ":" ++ driveProductId drive
-			++ "/) { print \\\\$v; last}\")"
-			]
-		]
-
--- Makes a USB drive with the given label automount, and unmount after idle
--- for a while.
-autoMountDrive :: Mount.Label -> Maybe FilePath -> Property DebianLike
-autoMountDrive = autoMountDrive' []
-
-autoMountDrive' :: [String] -> Mount.Label -> Maybe FilePath -> Property DebianLike
-autoMountDrive' mountunitadd label malias = propertyList desc $ props
-	& File.ownerGroup mountpoint (User "joey") (Group "joey")
-		`requires` File.dirExists mountpoint
-	& case malias of
-		Just t -> ("/media/joey/" ++ t) `File.isSymlinkedTo`
-			File.LinkTarget mountpoint
-		Nothing -> doNothing <!> doNothing
-	& File.hasContent ("/etc/systemd/system/" ++ mount)
-		([ "[Unit]"
-		, "Description=" ++ label
-		] ++ mountunitadd ++
-		[ "[Mount]"
-		-- avoid mounting whenever the block device is available,
-		-- only want to automount on demand
-		, "Options=noauto"
-		, "What=" ++ devfile
-		, "Where=" ++ mountpoint
-		, "[Install]"
-		, "WantedBy="
-		])
-		`onChange` Systemd.daemonReloaded
-	& File.hasContent ("/etc/systemd/system/" ++ automount)
-		[ "[Unit]"
-		, "Description=Automount " ++ label
-		, "[Automount]"
-		, "Where=" ++ mountpoint
-		, "TimeoutIdleSec=300"
-		, "[Install]"
-		, "WantedBy=multi-user.target"
-		]
-		`onChange` Systemd.daemonReloaded
-	& Systemd.enabled automount
-	& Systemd.started automount
-	& Sudo.sudoersDFile ("automount-" ++ label)
-		[ "joey ALL= NOPASSWD: " ++ sudocommands
-		]
-  where
-	devfile = "/dev/disk/by-label/" ++ label
-	mountpoint = "/media/joey/" ++ label
-	desc = "auto mount " ++ mountpoint
-	automount = svcbase ++ ".automount"
-	mount = svcbase ++ ".mount"
-	svcbase = Systemd.escapePath mountpoint
-	sudocommands = intercalate " , " $ map (\c -> "/bin/systemctl " ++ c)
-		[ "stop " ++ mountpoint
-		, "start " ++ mountpoint
-		]
-
 rsyncNetBorgRepo :: String -> [Borg.BorgRepoOpt] -> Borg.BorgRepo
 rsyncNetBorgRepo d os = Borg.BorgRepoUsing os' ("2318@usw-s002.rsync.net:" ++ d)
   where
@@ -1252,7 +1095,7 @@ hostapd2GhzConfig = HostapdConfig
 -- For wifi adapters such as the Alfa AWUS036ACHM
 --
 -- Note that for maximum speed, this needs channel 5 or 6.
--- This should make it be capable of 150 Mb/s.
+-- This should make it be capable of 300 Mb/s.
 hostapd2GhzConfig_mt76 :: HostapdConfig
 hostapd2GhzConfig_mt76 = HostapdConfig $ c ++ 
 	[ "ht_capab=[HT40+][HT40-][GF][SHORT-GI-20][SHORT-GI-40]"
@@ -1271,3 +1114,17 @@ hostapd5GhzConfig = HostapdConfig
 	, "wmm_enabled=1"
 	]
 
+thinkPadLedsOff :: Property Linux
+thinkPadLedsOff =
+	"/etc/systemd/system/thinkpad_leds_off.service" `File.hasContent`
+		[ "[Unit]"
+		, "After=suspend.target"
+		, "[Service]"
+		, "Type=simple"
+		, "ExecStart=sh -c 'echo 0 > /sys/devices/platform/thinkpad_acpi/leds/tpacpi::lid_logo_dot/brightness; echo 0 > /sys/devices/platform/thinkpad_acpi/leds/tpacpi::power/brightness'"
+		, "[Install]"
+		, "WantedBy=suspend.target"
+		]
+		`onChange` (Systemd.daemonReloaded
+			`before` Systemd.enabled "thinkpad_leds_off")
+
