@@ -314,6 +314,12 @@ nspawnService (Container name _ _) cfg = setup <!> teardown
 		, "--boot"
 		, "--directory=" ++ containerDir name
 		, "--machine=" ++ name
+		-- While propellChroot bind mounts the propellor directory,
+		-- when systemd stops and then restarts the machine, it
+		-- will mask any existing bind mounts to the directory.
+		-- So, tell systemd to bind mount the propellor directory
+		-- as well.
+		, "--bind=" ++ localdir
 		] ++ nspawnServiceParams cfg
 
 	overrideconfigured = File.hasContent overridefile overridecontent
