@@ -6,8 +6,10 @@ import Propellor.Types
 import Propellor.Types.Empty
 import Propellor.Types.Info
 
-import Data.Monoid
+import qualified Data.Semigroup as Sem
 import qualified Data.Map as M
+import Data.Monoid
+import Prelude
 
 data DockerInfo = DockerInfo
 	{ _dockerRunParams :: [DockerRunParam]
@@ -18,13 +20,16 @@ data DockerInfo = DockerInfo
 instance IsInfo DockerInfo where
 	propagateInfo _ = PropagateInfo False
 
-instance Monoid DockerInfo where
-	mempty = DockerInfo mempty mempty
-	mappend old new = DockerInfo
+instance Sem.Semigroup DockerInfo where
+	old <> new = DockerInfo
 		{ _dockerRunParams = _dockerRunParams old <> _dockerRunParams new
 		, _dockerContainers = M.union (_dockerContainers old) (_dockerContainers new)
 		}
 
+instance Monoid DockerInfo where
+	mempty = DockerInfo mempty mempty
+	mappend = (Sem.<>)
+
 instance Empty DockerInfo where
 	isEmpty i = and
 		[ isEmpty (_dockerRunParams i)
